# Codimension Documentation

This documentation does not cover everything.
It rather covers some practical topics. Please follow the links in the list below to select a particular area.


## General Topics

- [Technology](technology/technology.md)
- [CML - Codimension Markup Language](cml/cml.md)


## Graphics Pane

- [Smart zoom and other display options](smartzoom/smartzoom.md)
- [Grouping](grouping/grouping.md)


## Code Analysis

- [Dead code](deadcode/deadcode.md)
- [Complexity](complexity/complexity.md)
- [PyFlakes](pyflakes/pyflakes.md)
- [Dependencies](dependencies/dependencies.md)
- [Disassembling](disassembling/disassembling.md)
- Profiling (the documentation is coming soon)


## Miscellaneous

- [Plugins](plugins/plugins.md)
- [Markdown support (documenting your projects)](md/mdsupport.md)
- [Project explained](project/project.md)
- [IDE customization](editorsettings/editorsettings.md): mostly editor settings
- [Color schemes](colorschemes/colorschemes.md)
